EasyFormField class

Inheritance

Constructors

EasyFormField({Key? key, required String label, FieldType fieldType = FieldType.text, TextEditingController? controller, String? validator(String?)?, String? hintText, bool required = true, IconData? prefixIcon, IconData? suffixIcon, VoidCallback? onSuffixIconPressed, dynamic onChanged(String)?, dynamic onSaved(String?)?, bool enabled = true, int maxLines = 1, TextInputAction? textInputAction, FocusNode? focusNode, EdgeInsetsGeometry? contentPadding, InputBorder? border, InputBorder? enabledBorder, InputBorder? focusedBorder, InputBorder? errorBorder, InputBorder? focusedErrorBorder, InputBorder? disabledBorder, Color? fillColor, bool filled = false, TextStyle? labelStyle, TextStyle? hintStyle, TextStyle? textStyle, TextStyle? errorStyle, Color? cursorColor, double? cursorHeight, Radius? cursorRadius, double? cursorWidth, Color? focusColor, Color? hoverColor, Color? prefixIconColor, Color? suffixIconColor, double? borderRadius, BorderRadius? customBorderRadius, double? borderWidth, double? focusedBorderWidth, double? errorBorderWidth, Color? borderColor, Color? focusedBorderColor, Color? errorBorderColor, Color? disabledBorderColor, List<BoxShadow>? boxShadow, double? elevation, double? iconSize, EdgeInsetsGeometry? prefixIconPadding, EdgeInsetsGeometry? suffixIconPadding, EdgeInsetsGeometry? fieldMargin, EdgeInsetsGeometry? fieldPadding, DateTime? initialDate, DateTime? firstDate, DateTime? lastDate})
const

Properties

border InputBorder?
final
borderColor Color?
final
borderRadius double?
final
borderWidth double?
final
boxShadow List<BoxShadow>?
final
contentPadding EdgeInsetsGeometry?
final
controller TextEditingController?
final
cursorColor Color?
final
cursorHeight double?
final
cursorRadius Radius?
final
cursorWidth double?
final
customBorderRadius BorderRadius?
final
disabledBorder InputBorder?
final
disabledBorderColor Color?
final
elevation double?
final
enabled bool
final
enabledBorder InputBorder?
final
errorBorder InputBorder?
final
errorBorderColor Color?
final
errorBorderWidth double?
final
errorStyle TextStyle?
final
fieldMargin EdgeInsetsGeometry?
final
fieldPadding EdgeInsetsGeometry?
final
fieldType FieldType
final
fillColor Color?
final
filled bool
final
firstDate DateTime?
final
focusColor Color?
final
focusedBorder InputBorder?
final
focusedBorderColor Color?
final
focusedBorderWidth double?
final
focusedErrorBorder InputBorder?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
hintStyle TextStyle?
final
hintText String?
final
hoverColor Color?
final
iconSize double?
final
initialDate DateTime?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
labelStyle TextStyle?
final
lastDate DateTime?
final
maxLines int
final
onChanged → dynamic Function(String)?
final
onSaved → dynamic Function(String?)?
final
onSuffixIconPressed VoidCallback?
final
prefixIcon IconData?
final
prefixIconColor Color?
final
prefixIconPadding EdgeInsetsGeometry?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffixIcon IconData?
final
suffixIconColor Color?
final
suffixIconPadding EdgeInsetsGeometry?
final
textInputAction TextInputAction?
final
textStyle TextStyle?
final
validator String? Function(String?)?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<EasyFormField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited